@@ -63,7 +63,7 @@ klcddimmer::klcddimmer(const TQString& configFile, Type type, int actions, TQWid
     mBrightnessChooserFrame->setMainWidget(chooser);
     mBrightnessChooserFrame->resize(chooser->size());
 
-    connect(chooser, SIGNAL(valueUpdated()), this, SLOT(valueUpdate()));
+    connect(chooser, TQ_SIGNAL(valueUpdated()), this, TQ_SLOT(valueUpdate()));
 
     initContextMenu();
 
@@ -166,11 +166,11 @@ void klcddimmer::initContextMenu()
 {
   mContextMenu = new TDEPopupMenu(this);
   //mContextMenu->insertItem(SmallIcon("reload"), i18n("&Update Now"),
-  //                         this, SLOT(slotUpdateNow()), 0, -1, 2);
+  //                         this, TQ_SLOT(slotUpdateNow()), 0, -1, 2);
   mContextMenu->insertSeparator();
-  mContextMenu->insertItem(SmallIcon("klcddimmer"), i18n("&About KLcdDimmer"), this, SLOT(about()));
+  mContextMenu->insertItem(SmallIcon("klcddimmer"), i18n("&About KLcdDimmer"), this, TQ_SLOT(about()));
   mContextMenu->insertItem(SmallIcon("configure"),
-                           i18n("&Configure KLcdDimmer..."), this, SLOT(preferences()));
+                           i18n("&Configure KLcdDimmer..."), this, TQ_SLOT(preferences()));
   setCustomMenu(mContextMenu);
 }
 
@@ -201,7 +201,7 @@ void klcddimmer::valueUpdate()
 
 extern "C"
 {
-    KPanelApplet* init( TQWidget *parent, const TQString& configFile)
+    KDE_EXPORT KPanelApplet* init( TQWidget *parent, const TQString& configFile)
     {
         TDEGlobal::locale()->insertCatalogue("klcddimmer");
         return new klcddimmer(configFile, KPanelApplet::Normal,
